<div align="center">
    <img src="https://raw.githubusercontent.com/he-yaowen/charsi/main/logo/charsi.png"/>
</div>

![License](https://img.shields.io/github/license/he-yaowen/charsi)
![Python Versions](https://img.shields.io/pypi/pyversions/charsi)
![PyPI Version](https://img.shields.io/pypi/v/charsi)
![Unit Test](https://img.shields.io/github/actions/workflow/status/he-yaowen/charsi/unit-test.yml)

# Charsi

A command-line tool to help game modders build string resources
for [Diablo II: Resurrected][1].

## Introduction

In the classic version of Diablo II, there was a very famous hacking tool called
[Maphack][2], which could easily configure texts displayed in game. Now in
Diablo II: Resurrected, you can directly modify the JSON files to change texts
in game, but the workload is high, and it's easy to make mistakes.

[Charsi][3] is the blacksmith in the Rogue Encampment in Act I of Diablo II, and
can imbue any normal item of the player's choice.

This tool named charsi, can imbue game strings with your recipes which are in a
format similar to Maphack configurations.

## License

Copyright (C) 2022 HE Yaowen <he.yaowen@hotmail.com>

The GNU General Public License (GPL) version 3, see [COPYING](./COPYING).

[1]: https://diablo2.blizzard.com

[2]: https://diablo2.diablowiki.net/Maphack

[3]: https://diablo.fandom.com/wiki/Charsi
